#include "mainwindow.h"

#include <QTreeWidgetItem>
#include <QGraphicsEllipseItem>
#include <QMimeData>
#include <QGraphicsSceneDragDropEvent>

class MyEllipse : public QGraphicsEllipseItem
{
protected:
    void dragEnterEvent(QGraphicsSceneDragDropEvent *event)
    {
        const QMimeData * data = event->mimeData();
        // if (data->hasText())
        //     event->acceptProposedAction ();
        if (data->hasColor())
            event->acceptProposedAction ();
    }

    void dropEvent(QGraphicsSceneDragDropEvent *event)
    {
        const QMimeData * data = event->mimeData();
        if (data->hasColor())
        {
            QColor color = qvariant_cast <QColor> (data->colorData());
            this->setBrush (color);
        }

    }
};

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent)
{
    setupUi(this);

    scene = new QGraphicsScene;
    graphicsView->setScene (scene);
    // graphicsView->setAcceptDrops(true);

    for (int i = 1; i <=3 ; i++)
    {
       QGraphicsEllipseItem * e = new MyEllipse;
       e->setRect (10, 10, 200, 100);
       e->setPen (QColor ("blue"));
       e->setBrush (QColor ("yellow"));
       e->setFlag (QGraphicsItem::ItemIsMovable);
       e->setFlag (QGraphicsItem::ItemIsSelectable);
       e->setAcceptDrops(true);
       scene->addItem (e);
    }


    auto item = new QTreeWidgetItem;
    item->setText (0, "root");
    treeWidget->addTopLevelItem (item);

    auto item2 = new QTreeWidgetItem;
    item2->setText (0, "branch");
    item->addChild (item2);

    item2 = new QTreeWidgetItem;
    item2->setText (0, "branch 2");
    item->addChild (item2);

    item2 = new QTreeWidgetItem;
    item2->setText (0, "branch 3");
    item->addChild (item2);

    auto list = new QTreeWidgetItem;
    list->setText (0, "list");
    item2->addChild (list);

    item->setExpanded(true);
}

#include <QDrag>
#include <QMimeData>

void MainWindow::on_pushButton_pressed()
{
    QDrag * drag = new QDrag (this);

    QMimeData * data = new QMimeData;
    data->setText ("Drag and drop");
    data->setColorData (QColor ("orange"));

    QPixmap  img (16, 16);
    QPainter p (&img);
    // p.begin(img);
    p.setPen (QColor ("lime"));
    p.setBrush (QColor ("red"));
    p.drawEllipse(1, 1, 14, 14);

    drag->setPixmap(img);

    drag->setMimeData (data);
    drag->start ();
    // drag->start (Qt::CopyAction | Qt::MoveAction | Qt::LinkAction);
}
